@@ -2,6 +2,7 @@
 
 from __future__ import annotations
 
+import inspect
 import math
 from functools import lru_cache
 
@@ -117,7 +118,7 @@ class ArrayModuleNumpyLike(NumpyLike[ArrayLikeT]):
         *,
         dtype: DTypeLike | None = None,
     ) -> ArrayLikeT:
-        return self._module.full(shape, fill_value, dtype=dtype)
+        return self._module.full(shape, self._module.array(fill_value), dtype=dtype)
 
     def zeros_like(
         self, x: ArrayLikeT | PlaceholderArray, *, dtype: DTypeLike | None = None
@@ -145,7 +146,9 @@ class ArrayModuleNumpyLike(NumpyLike[ArrayLikeT]):
         if isinstance(x, PlaceholderArray):
             return self.full(x.shape, fill_value, dtype=dtype or x.dtype)
         else:
-            return self._module.full_like(x, fill_value, dtype=dtype)
+            return self._module.full_like(
+                x, self._module.array(fill_value), dtype=dtype
+            )
 
     def arange(
         self,
@@ -173,7 +176,10 @@ class ArrayModuleNumpyLike(NumpyLike[ArrayLikeT]):
         assert not isinstance(x1, PlaceholderArray)
         assert not isinstance(x2, PlaceholderArray)
         if equal_nan:
-            both_nan = self._module.logical_and(x1 == np.nan, x2 == np.nan)
+            # Only newer numpy.array_equal supports the equal_nan parameter.
+            both_nan = self._module.logical_and(
+                self._module.isnan(x1), self._module.isnan(x2)
+            )
             both_equal = x1 == x2
             return self._module.all(self._module.logical_or(both_equal, both_nan))
         else:
@@ -390,14 +396,26 @@ class ArrayModuleNumpyLike(NumpyLike[ArrayLikeT]):
 
     def unique_values(self, x: ArrayLikeT) -> ArrayLikeT:
         assert not isinstance(x, PlaceholderArray)
-        return self._module.unique(
-            x,
-            return_counts=False,
-            return_index=False,
-            return_inverse=False,
-            equal_nan=False,
+        np_unique_accepts_equal_nan = (
+            "equal_nan" in inspect.signature(self._module.unique).parameters
         )
 
+        if np_unique_accepts_equal_nan:
+            return self._module.unique(
+                x,
+                return_counts=False,
+                return_index=False,
+                return_inverse=False,
+                equal_nan=False,
+            )
+        else:
+            return self._module.unique(
+                x,
+                return_counts=False,
+                return_index=False,
+                return_inverse=False,
+            )
+
     def unique_all(self, x: ArrayLikeT) -> UniqueAllResult:
         assert not isinstance(x, PlaceholderArray)
         values, indices, inverse_indices, counts = self._module.unique(
