@@ -39,7 +39,7 @@ from awkward.contents.content import (
     ToArrowOptions,
 )
 from awkward.errors import AxisError
-from awkward.forms.form import Form
+from awkward.forms.form import Form, FormKeyPathT
 from awkward.forms.indexedoptionform import IndexedOptionForm
 from awkward.index import Index
 
@@ -202,6 +202,14 @@ class IndexedOptionArray(IndexedOptionMeta[Content], Content):
             form_key=form_key,
         )
 
+    def _form_with_key_path(self, path: FormKeyPathT) -> IndexedOptionForm:
+        return self.form_cls(
+            self._index.form,
+            self._content._form_with_key_path((*path, None)),
+            parameters=self._parameters,
+            form_key=repr(path),
+        )
+
     def _to_buffers(
         self,
         form: Form,
@@ -592,7 +600,7 @@ class IndexedOptionArray(IndexedOptionMeta[Content], Content):
 
             offsets, flattened = next._offsets_and_flattened(axis, depth)
 
-            if offsets.length == 0:
+            if offsets.length is not unknown_length and offsets.length == 0:
                 return (
                     offsets,
                     ak.contents.IndexedOptionArray(
@@ -761,6 +769,7 @@ class IndexedOptionArray(IndexedOptionMeta[Content], Content):
             if isinstance(
                 array, (ak.contents.IndexedOptionArray, ak.contents.IndexedArray)
             ):
+                array = array._trim()  # see: #3185 and #3119
                 # If we're merging an option, then merge parameters before pulling out `content`
                 parameters = parameters_intersect(parameters, array._parameters)
                 contents.append(array.content)
@@ -983,9 +992,10 @@ class IndexedOptionArray(IndexedOptionMeta[Content], Content):
                 and parents.nplike is self._backend.index_nplike
                 and nextparents.nplike is self._backend.index_nplike
             )
+
             self._backend.maybe_kernel_error(
                 self._backend[
-                    "awkward_IndexedArray_local_preparenext",
+                    "awkward_IndexedArray_local_preparenext_64",
                     nextoutindex.dtype.type,
                     starts.dtype.type,
                     parents.dtype.type,
@@ -1258,9 +1268,10 @@ class IndexedOptionArray(IndexedOptionMeta[Content], Content):
             and parents.nplike is self._backend.index_nplike
             and nextparents.nplike is self._backend.index_nplike
         )
+
         self._backend.maybe_kernel_error(
             self._backend[
-                "awkward_IndexedArray_local_preparenext",
+                "awkward_IndexedArray_local_preparenext_64",
                 nextoutindex.dtype.type,
                 starts.dtype.type,
                 parents.dtype.type,
@@ -1342,7 +1353,7 @@ class IndexedOptionArray(IndexedOptionMeta[Content], Content):
 
         self._backend.maybe_kernel_error(
             self._backend[
-                "awkward_IndexedArray_local_preparenext",
+                "awkward_IndexedArray_local_preparenext_64",
                 nextoutindex.dtype.type,
                 starts.dtype.type,
                 parents.dtype.type,
@@ -1573,6 +1584,9 @@ class IndexedOptionArray(IndexedOptionMeta[Content], Content):
             options,
         )
 
+    def _to_cudf(self, cudf: Any, mask: Content | None, length: int):
+        return self.to_ByteMaskedArray(True)._to_cudf(cudf, mask, length)
+
     def _to_backend_array(self, allow_missing, backend):
         nplike = backend.nplike
         index_nplike = backend.index_nplike
@@ -1739,8 +1753,8 @@ class IndexedOptionArray(IndexedOptionMeta[Content], Content):
 
         index = self._index.raw(numpy)
         not_missing = index >= 0
-
-        nextcontent = self._content._carry(ak.index.Index(index[not_missing]), False)
+        content = ak.to_backend(self._content, "cpu", highlevel=False)
+        nextcontent = content._carry(ak.index.Index(index[not_missing]), False)
         out = nextcontent._to_list(behavior, json_conversions)
 
         for i, isvalid in enumerate(not_missing):
@@ -1765,6 +1779,28 @@ class IndexedOptionArray(IndexedOptionMeta[Content], Content):
             )
         )
 
+    def _trim(self) -> Self:
+        nplike = self._backend.index_nplike
+
+        if not nplike.known_data or self._index.length == 0:
+            return self
+
+        idx_buf = nplike.asarray(self._index.data, copy=True)
+        only_positive = idx_buf >= 0
+
+        # no positive index at all
+        if not nplike.any(only_positive):
+            return self
+
+        min_idx = nplike.min(idx_buf[only_positive])
+        max_idx = nplike.max(idx_buf[only_positive])
+        idx_buf[only_positive] -= min_idx
+        index = Index(idx_buf)
+
+        # left and right trim
+        content = self._content._getitem_range(min_idx, max_idx + 1)
+        return IndexedOptionArray(index, content, parameters=self._parameters)
+
 
 def create_missing_data(dtype, backend):
     """Create missing data based on the input dtype
